from rich.style import Style

# Rich styles for console UI
RICH_STYLE_YELLOW = Style(color="yellow", bold=False)
RICH_STYLE_GREEN = Style(color="green", bold=False)
RICH_STYLE_BLUE = Style(color="blue", bold=False)
RICH_STYLE_RED = Style(color="red", bold=False)
RICH_STYLE_GRAY = Style(color="grey66", bold=False)

RICH_STYLE_YELLOW_BOLD = Style(color="yellow", bold=True)
RICH_STYLE_GREEN_BOLD = Style(color="green", bold=True)
RICH_STYLE_BLUE_BOLD = Style(color="blue", bold=True)
RICH_STYLE_RED_BOLD = Style(color="red", bold=True)

RICH_STYLE_FILE_ACCENT_BOLD = Style(color="bright_cyan", bold=True)
RICH_STYLE_FILE_PATH = Style(color="bright_white", bold=False)

CODE_THEME = "lightbulb"
